@@ -1216,6 +1216,7 @@ class Builder(Update):
         """
         proprietary = ["nvidia", "fglrx"]
         video = self.clVars.Get('cl_builder_x11_video_drv')
+        audio = self.clVars.Get('cl_builder_audio')
         locale = self.clVars.Get('cl_builder_locale_lang')
         timezone = self.clVars.Get('cl_builder_timezone')
         params = ["%s:%s" % (CmdlineParams.Locale, locale),
@@ -1230,6 +1231,8 @@ class Builder(Update):
             if current_video == video and video != "default":
                 composite = self.clVars.Get('cl_builder_x11_composite')
                 params.append("%s:%s" % (CmdlineParams.Composite, composite))
+        if audio == "alsa":
+            params.append("audio:alsa")
         calculate_param = ",".join(params)
         if self.clVars.GetBool('cl_builder_docache_set'):
             return "%s docache" % calculate_param
